@@ -7,6 +7,7 @@ import json
 import os
 import time
 import requests
+from requests.adapters import HTTPAdapter
 
 from kdl.endpoint import EndPoint
 from kdl.exceptions import KdlException, KdlNameError, KdlTypeError, KdlStatusError
@@ -318,9 +319,18 @@ class Client:
         return res
 
     def _get_secret_token(self):
-        r = requests.post(url='https://' + EndPoint.GetSecretToken.value, data={'secret_id': self.auth.secret_id, 'secret_key': self.auth.secret_key})
-        if r.status_code != 200:
-            raise KdlStatusError(r.status_code, r.content.decode('utf8'))
+        try:
+            s = requests.Session()
+            s.mount('http://', HTTPAdapter(max_retries=3))  # 请求失败重试3次
+            s.mount('https://', HTTPAdapter(max_retries=3))
+            r = requests.post(url='https://' + EndPoint.GetSecretToken.value,
+                          data={'secret_id': self.auth.secret_id, 'secret_key': self.auth.secret_key}, timeout=(5, 6))
+            if r.status_code != 200:
+                raise KdlStatusError(r.status_code, r.content.decode('utf8'))
+        except requests.exceptions.RequestException as e:
+            pass  # TODO: 重试3次失败处理
+            raise e
+
         res = json.loads(r.content.decode('utf8'))
         code, msg = res['code'], res['msg']
         if code != 0:
@@ -334,7 +344,7 @@ class Client:
         with open(SECRET_PATH, 'r') as f:
             token_info = f.read()
         secret_token, expire, _time = token_info.split('|')
-        if float(_time) + float(expire) - 3 * 60 < time.time():  # 还有3分钟过期时更新
+        if float(_time) + float(expire) - 3 * 60 <= time.time():  # 还有3分钟过期时更新
             secret_token, expire, _time = self._get_secret_token()
             with open(SECRET_PATH, 'w') as f:
                 f.write(secret_token + '|' + expire + '|' + _time)
@@ -370,7 +380,7 @@ class Client:
             params["signature"] = self.auth.sign_str(raw_str)
         elif sign_type == "token":
             secret_token = self.get_secret_token()
-            params['signature'] = secret_token
+            params['secret_token'] = secret_token
         else:
             raise KdlNameError("unknown sign_type {}".format(sign_type))
 
@@ -386,7 +396,8 @@ class Client:
             if method == "GET":
                 r = requests.get("https://" + endpoint, params=params)
             elif method == "POST":
-                r = requests.post("https://" + endpoint, data=params, headers={"Content-Type": "application/x-www-form-urlencoded"})
+                r = requests.post("https://" + endpoint, data=params)
+
             if r.status_code != 200:
                 raise KdlStatusError(r.status_code, r.content.decode('utf8'))
             try:
